/* $Id: ruby_xml_xinclude.h 612 2008-11-21 08:01:29Z cfis $ */

/* Please see the LICENSE file for copyright and distribution information */

#ifndef __rxml_XINCLUDE__
#define __rxml_XINCLUDE__

extern VALUE cXMLXInclude;
extern VALUE eXMLXIncludeError;

void ruby_init_xml_xinclude(void);

#endif
